@@ -53,6 +53,7 @@ static const PkEnumMatch enum_info_icon_name[] = {
 	{PK_INFO_ENUM_COLLECTION_AVAILABLE,	"pk-collection-available"},
 	{PK_INFO_ENUM_FINISHED,			"dialog-information"},
 	{PK_INFO_ENUM_REINSTALLING,		"dialog-information"},
+	{PK_INFO_ENUM_DOWNGRADING,		"pk-package-update"},
 	{0, NULL}
 };
 
@@ -251,6 +252,7 @@ static const PkEnumMatch enum_message_icon_name[] = {
 	{PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,	"dialog-information"},
 	{PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED,	"dialog-information"},
 	{PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED,	"dialog-information"},
+	{PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED,	"dialog-warning"},
 	{0, NULL}
 };
 
@@ -878,6 +880,11 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 	case PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED:
 		text = _("Automatic cleanup is being ignored");
 		break;
+	case PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED:
+		text = _("The package download failed");
+/* string-freeze: uncomment better translation */
+//		text = _("Software source download failed");
+		break;
 	default:
 		egg_warning ("message unrecognised: %i", message);
 	}
@@ -1354,11 +1361,11 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		break;
 	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
 		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Simulating the install");
+		text = _("Simulating the install of files");
 		break;
 	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
 		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Simulating the install of files");
+		text = _("Simulating the install");
 		break;
 	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
 		/* TRANSLATORS: The role of the transaction, in present tense */
@@ -1510,11 +1517,11 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		break;
 	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
 		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Simulated the install");
+		text = _("Simulated the install of files");
 		break;
 	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
 		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Simulated the install of files");
+		text = _("Simulated the install");
 		break;
 	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
 		/* TRANSLATORS: The role of the transaction, in past tense */
